# unitorch.models.peft

## BloomLoraForClassification

::: unitorch.models.peft.BloomLoraForClassification
    
## BloomLoraForGeneration

::: unitorch.models.peft.BloomLoraForGeneration

## LlamaLoraForClassification

::: unitorch.models.peft.LlamaLoraForClassification
    
## LlamaLoraForGeneration

::: unitorch.models.peft.LlamaLoraForGeneration
